AuthManager class

Constructors

AuthManager(Dio dio)

Properties

accessToken ↔ String?
getter/setter pair
dio → Dio
final
hashCode → int
The hash code for this object.
no setterinherited
refreshTokenStr ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshToken() → Future<bool>
retryRequest(DioException err) → Future<Response?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited