AdvancedDioHelper class

Properties

authManager AuthManager
getter/setter pair
dio ↔ Dio
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String url, {dynamic data}) Future<Response>
DELETE request
get(String url, {Map<String, dynamic>? queryParams, String? cacheKey}) Future<Response>
GET request url is required queryParams optional query parameters cacheKey optional key for caching offline responses
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post(String url, {dynamic data}) Future<Response>
POST request
put(String url, {dynamic data}) Future<Response>
PUT request
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance AdvancedDioHelper
final